@@ -1,4 +1,4 @@
-GOOF----LE-4-2.0J      ] 4    hw      ] g  guile	 	g  process-use-modules	 	 	g  gnucash	g  	app-utils	 		 	
+GOOF----LE-8-2.0=J      ] 4    hw      ] g  guile	 	g  process-use-modules	 	 	g  gnucash	g  	app-utils	 		 	
 g  Ind	f  Individual, Joint, etc.	f  Umsatzsteuer-Kennzahlen	
  	g  Other	f  None	f  &Keine Steuerberichtsoptionen vorhanden	 	g  txf-tax-entity-types	g  assv	g  gnc:tax-type-txf-get-code-info	g  gnc:txf-get-tax-entity-type	g  'gnc:txf-get-tax-entity-type-description	g  map	g  car	g  !gnc:txf-get-tax-entity-type-codes	g  gnc:txf-get-code-info	g  gnc:txf-get-payer-name-source	g  gnc:txf-get-form	g  gnc:txf-get-description	g  gnc:txf-get-format	g  gnc:txf-get-multiple	 g  gnc:txf-get-category-key	!g  string->symbol	"g  
 vector-length	#g  gnc:txf-get-line-data	$g  gnc:txf-get-last-year	%g  txf-help-strings	&f  Keine Hilfe verfgbar, da nur Gruppenberschrift.
@@ -26,94 +26,94 @@ Fehlermeldungen + Dankschreiben an: stoll@bomhardt.de	'g  gnc:txf-get-help	(f
 f  ZAnrechnung (Abzug) der festgesetzten Sondervorauszahlung (1/11) fr Dauerfristverlngerung9	
 	 g  txf-expense-categories
 f  zu anderen Steuerstzen9
-	 g  txf-asset-categoriesg  txf-liab-eq-categoriesg  gnc:make-string-optiong  gnc:*tax-label*g  gnc:*tax-nr-label*f  af  *The electronic tax number of your businessg  gnc:register-optiong  book-options-generatorg  !gnc-register-kvp-option-generatorg  QOF-ID-BOOK-SCMC 5    h  q  ] 4	 >  "  G  
+	 g  txf-asset-categoriesg  txf-liab-eq-categoriesg  gnc:make-string-optiong  gnc:*tax-label*g  gnc:*tax-nr-label*f  af  *The electronic tax number of your businessg  gnc:register-optiong  book-options-generatorg  !gnc-register-kvp-option-generatorg  QOF-ID-BOOK-SCMC 5    h  s  ] 4	 >  "  G  
 
- R   h0   S  ]4 5$  4 5$  CCC     K      g  tax-entity-types
-		+ g  	type-code		+ g  index			+ g  tax-entity-type			)  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+ R   h0   U  ]4 5$  4 5$  CCC     M      g  tax-entity-types
+		+ g  	type-code		+ g  index			+ g  tax-entity-type			)  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	6
-		7			7			8			8		 	9		#	:		&	:	 			+	  g  nameg  gnc:tax-type-txf-get-code-info CR  h      ] 
+		7			7			8			8		 	9		#	:		&	:	 			+	  g  nameg  gnc:tax-type-txf-get-code-info CR        h      ] 
 6            g  	type-code
-		  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	=
-		>	 		  g  nameg  gnc:txf-get-tax-entity-type CR   h      ] 6            g  	type-code
-		  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		>	 		  g  nameg  gnc:txf-get-tax-entity-type CR h      ] 6            g  	type-code
+		  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	@
-		A	 		  g  nameg  'gnc:txf-get-tax-entity-type-description CR     h      ] 6             g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		A	 		  g  nameg  'gnc:txf-get-tax-entity-type-description CR   h      ] 6             g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	C
 	
 	D	 		
 
-  g  nameg  !gnc:txf-get-tax-entity-type-codes CR       h     ] 
+  g  nameg  !gnc:txf-get-tax-entity-type-codes CR     h     ] 
 6          g  
 categories
 		
  g  code		
  g  tax-entity-type			
-  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	F
 	
 	G	 		
-	  g  nameg  gnc:txf-get-payer-name-source CR   h      ] 6          g  
+	  g  nameg  gnc:txf-get-payer-name-source CR h      ] 6          g  
 categories
 		
  g  code		
  g  tax-entity-type			
-  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	H
 	
 	I	 		
-	  g  nameg  gnc:txf-get-form CR        h      ] 	6         g  
+	  g  nameg  gnc:txf-get-form CR      h      ] 	6         g  
 categories
-		 g  code		 g  tax-entity-type			  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		 g  code		 g  tax-entity-type			  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	J
-		K	 			  g  nameg  gnc:txf-get-description CR h      ] 	6         g  
+		K	 			  g  nameg  gnc:txf-get-description CR       h      ] 	6         g  
 categories
-		 g  code		 g  tax-entity-type			  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		 g  code		 g  tax-entity-type			  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	L
-		M	 			  g  nameg  gnc:txf-get-format CR      h      ] 	6         g  
+		M	 			  g  nameg  gnc:txf-get-format CR    h      ] 	6         g  
 categories
-		 g  code		 g  tax-entity-type			  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		 g  code		 g  tax-entity-type			  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	N
-		O	 			  g  nameg  gnc:txf-get-multiple CR    h      ] 	6         g  
+		O	 			  g  nameg  gnc:txf-get-multiple CR  h     ] 	6         g  
 categories
-		 g  code		 g  tax-entity-type			  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		 g  code		 g  tax-entity-type			  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	P
-		Q	 			  g  nameg  gnc:txf-get-category-key C R!"  hp     ]445 5$  V445 545$  
+		Q	 			  g  nameg  gnc:txf-get-category-key C R!"        hp     ]445 5$  V445 545$  
 45"  $  45	"  $  C 	6C          g  
 categories
-		l g  code		l g  tax-entity-type			l g  tax-entity-codes		#	j g  category		@	j  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		l g  code		l g  tax-entity-type			l g  tax-entity-codes		#	j g  category		@	j  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	R
-		S			S			S			S			T	$		T	*	"	T	$	#	T		#	T		&	V		2	V		3	W		@	T		H	Y		I	Y	&	N	Y	5	P	Y	&	S	Y	#	X	Y		\	Y		j	[	 		l	  g  nameg  gnc:txf-get-line-data C#R!" hp     ]445 5$  V445 545$  
+		S			S			S			S			T	$		T	*	"	T	$	#	T		#	T		&	V		2	V		3	W		@	T		H	Y		I	Y	&	N	Y	5	P	Y	&	S	Y	#	X	Y		\	Y		j	[	 		l	  g  nameg  gnc:txf-get-line-data C#R!"       hp     ]445 5$  V445 545$  
 45"  $  45	"  $  C 	6C          g  
 categories
-		l g  code		l g  tax-entity-type			l g  tax-entity-codes		#	j g  category		@	j  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		l g  code		l g  tax-entity-type			l g  tax-entity-codes		#	j g  category		@	j  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	]
-		^			^			^			^			_	$		_	*	"	_	$	#	_		#	_		&	a		2	a		3	b		@	_		H	d		I	d	&	N	d	5	P	d	&	S	d	#	X	d		\	d		j	f	 		l	  g  nameg  gnc:txf-get-last-year C$R%&   h      ]
-45$  CC            g  
+		^			^			^			^			_	$		_	*	"	_	$	#	_		#	_		&	a		2	a		3	b		@	_		H	d		I	d	&	N	d	5	P	d	&	S	d	#	X	d		\	d		j	f	 		l	  g  nameg  gnc:txf-get-last-year C$R%& h      ]
+45$  CC            g  
 categories
-		 g  code		 g  pair			  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		 g  code		 g  pair			  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	i
 		j			j			k			l			m	 			  g  nameg  gnc:txf-get-help C'R!(
- hP     ]445 5$  74$  "  45 5$  "  6C         g  
+       hP     ]445 5$  74$  "  45 5$  "  6C         g  
 categories
-		M g  tax-entity-type		M g  tax-entity-code-list-pair		1	K g  tax-entity-codes		A	K  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		M g  tax-entity-type		M g  tax-entity-code-list-pair		1	K g  tax-entity-codes		A	K  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 	r
 		s			s			s			s			t	(		t	H		t	2	 	t	.	"	u	/	'	v	/	1	t	(	1	t		9	x		<	y	#	A	z	#	A	t		K	{	 		M	  g  nameg  gnc:txf-get-codes C)R(
-!      hP     ]4$  "  45 5$  "  45$  CC           g  
+!    hP     ]4$  "  45 5$  "  45$  CC           g  
 categories
-		K g  code		K g  index			K g  tax-entity-type			K g  tax-entity-code-list-pair			K g  tax-entity-codes		/	K g  category		:	K  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+		K g  code		K g  index			K g  tax-entity-type			K g  tax-entity-code-list-pair			K g  tax-entity-codes		/	K g  category		:	K  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
  
 	 	$		 	D	
  	.	 	*	 	.	 	.	 	$	 		' 		* 		/ 		/ 		2 		: 		B 		E 		H 	 		K	  g  nameg  gnc:txf-get-code-info CR*./236 7R
 8;<>?ABDEGHKLOPSTWXZ[^_abefijmnqruvxy{| '8;  R
 8;<>ƌʌ͌ЌԌ،܌  8;  R
 8;<>ƌʌ͌Ќ،܌  8;  R
-8;<>_aruvx 8;  R(   h      ]	45 6           g  options
+8;<>_aruvx 8;  R( h      ]	45 6           g  options
 		 g  
-new-option		  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm
+new-option		  g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm
 U
 	Z		\		
-\		\	:	Z		Y		W	 			  g  nameg  book-options-generator CRiii6 i      g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i686/src/gnucash-2.6.20/src/tax/us/txf-de_DE.scm		/
+\		\	:	Z		Y		W	 			  g  nameg  book-options-generator CRiii6       k      g  filenamef  Z/usr/src/ports/gnucash/gnucash-2.6.21-1.x86_64/src/gnucash-2.6.21/src/tax/us/txf-de_DE.scm		/
 		3				3			3			4			 	4		!	4		$	2		'	1
 	6
 	=
@@ -121,29 +121,26 @@ new-option		  g  filenamef  X/usr/src/ports/gnucash/gnucash-2.6.20-1.i6
 	C
 	F
 	H
-	J
-	,	L
+	J
+	>	L
 
-N	N
-r	P
+`	N
+	P
 
 	R
-#	]
-g	i
-~	r
- 
- 		 	 	 		 	 	 		 	 	 	 
- 	  		 	 	 		 	 	
- 		 	
- 	 		 	 	 		 	 	 		 	 	 		  	! 	# 		% 	& 	( 		* 	+ 	- 		/ 	0 	2 		4 	5 	7 		9 	: 	< 		> 	? 	A 		C 	D 	F 		H 	I 	K 		M 	N 	P 		R 	S 	U 		W 	X 	Z 		\ 	] 	_ 		a 	b 	d 		f 	g 	i 		k 	l 	n 		p 	q 	s 		u 	v 	x 		z 	{ 	} 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 	 	 	
+E	]
+	i
+	r
+ 
+ 		 	 	 		 	 	 		 	  	# 	& 
+( 	* 		, 	- 	/ 		1 	2 	4 		6 	7 	9 		; 	< 	> 		@ 	A 	C 		E 	F 	H 		J 	K 	M 		O 	P 	R 		T 	U 	W 		Y 	Z 	\ 		^ 	_ 	a 		c 	d 	f 		h 	i 	k 		m 	n 	p 		r 	s 	u 		w 	x 	z 		| 	} 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 	 	 	
  	 	 	  
- 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	 		 	 	  		 	 	 		 	 	
- 		 	
- 	 		 	 	 		 	 	 		 	 	 		  	! 	# 		% 	& 	( 		* 	+ 	- 		/ 	0 	2 		4 	5 	7 		9 	: 	= 		@ 	A 	D 		G 	H 	J 		L 	M 	P 		S 	T 	W 	Y 	[		]	^	a 	d h 
-j		l		n	o	q		s	t	v		x	y	{		}	~																																																									 		 	 	!		!	!	"		"	"	#		#	#	$		$	$	
-	(	*		*	*	)	
-1	3		3	3	4		4	4	6		6	6		7		7	7	8		8	8	9		9	9	;		;	;	<		<	 <	"=		$=	%=	'>		)>	*>	,@		.@	/@	1A		3A	4A	6B		8B	9B	;C		=C	>C	@D		BD	CD	EF		GF	HF	JG		LG	MG	OH		QH	RH	UI		XI	YI	\2	^M	`O		bO	cO	fN	i0m/
+ 	 		 	  	 		 	 	 			 	
+ 	 		 	 	 		 	 	 		 	 	 		 	 	  		" 	# 	% 		' 	( 	* 		, 	- 	/ 		1 	2 	4 		6 	7 	9 		; 	< 	> 		@ 	A 	C 		E 	F 	H 		J 	K 	M 		O 	P 	R 		T 	U 	W 		Y 	Z 	\ 		^ 	_ 	a 		c 	d 	g 		j 	k 	n 		q 	r 	t 		v 	w 	z 		} 	~ 	 	 					 	  
+																																																																										 		 	 	!		!	!	"		"	"	#		#	#	$		$	$	
+	(	*		*	*	)	 
+"1	$3		&3	'3	)4		+4	,4	.6		06	16	37		57	67	88		:8	;8	=9		?9	@9	B;		D;	E;	G<		I<	J<	L=		N=	O=	Q>		S>	T>	V@		X@	Y@	[A		]A	^A	`B		bB	cB	eC		gC	hC	jD		lD	mD	oF		qF	rF	tG		vG	wG	yH		{H	|H	I		I	I	2	M	O		O	O	N	0/
 U
-_
-	
+	_
+		
    C6 
\ No newline at end of file
